@@ -13,16 +13,16 @@
 #' @param by_route default TRUE, if FALSE then calculate headway for any line coming through the stop in the same direction on the same schedule. 
 #' @param wide (optional) if true, then return a wide rather than tidy data frame
 #' @export
-#' @return a gtfs_obj with a dataframe of stops (gtfs_obj$.$stops_frequency) with a "Trips" variable representing the count trips taken through each stop for a route within a given time frame
+#' @return dataframe of stops (gtfs_obj$.$stops_frequency) with a "Trips" variable representing the count trips taken through each stop for a route within a given time frame
 #' @importFrom dplyr %>%
 #' @importFrom rlang .data !! quo enquo
 #' @importFrom stats median sd
 #' @importFrom tidyr spread
 #' @examples 
 #' data(gtfs_obj)
-#' gtfs_obj <- get_stop_frequency(gtfs_obj)
-#' x <- order(gtfs_obj$.$stops_frequency$headway)
-#' head(gtfs_obj$.$stops_frequency_df[x,])
+#' stop_frequency <- get_stop_frequency(gtfs_obj)
+#' x <- order(stop_frequency$headway)
+#' head(stop_frequency[x,])
 
 get_stop_frequency <- function(gtfs_obj,
                             start_hour=6,
@@ -53,7 +53,6 @@ get_stop_frequency <- function(gtfs_obj,
       dplyr::group_by(.data$direction_id,
                       .data$stop_id,
                       .data$service_id) %>%
-      most_frequent_service() %>%
       dplyr::summarise(departures = dplyr::n())
   }
   else if (by_route == TRUE) {
@@ -62,7 +61,6 @@ get_stop_frequency <- function(gtfs_obj,
                     .data$direction_id,
                     .data$stop_id,
                     .data$service_id) %>%
-    most_frequent_service() %>%
       dplyr::summarise(departures = dplyr::n())
   }
   # TODO we should only use seconds
@@ -70,8 +68,8 @@ get_stop_frequency <- function(gtfs_obj,
   t1 <- end_hour - start_hour
   minutes1 <- 60 * t1
   stop_time_trips$headway <-
-    round(minutes1 / stop_time_trips$departures,
-          digits = 4)
+    as.integer(round(minutes1 / stop_time_trips$departures,
+          digits = 0))
   if (wide == TRUE){
     stop_time_trips <- stop_time_trips %>%
       dplyr::select(-.data$departures, -.data$service) %>%
@@ -80,8 +78,7 @@ get_stop_frequency <- function(gtfs_obj,
   }
   stops_frequency <- stop_time_trips %>% 
     tibble::as_tibble()
-  gtfs_obj$.$stops_frequency <- stops_frequency
-  return(gtfs_obj)
+  return(stops_frequency)
 }
 
 #' Get Route Frequency
@@ -90,20 +87,19 @@ get_stop_frequency <- function(gtfs_obj,
 #' Consider using this instead, as it will be more accurate than what 
 #' tidytransit calculates. 
 #' 
-#' should take: 
 #' @param gtfs_obj a list of gtfs dataframes as read by the trread package.
 #' @param start_hour (optional) an integer, default 6 (6 am)
 #' @param end_hour (optional) an integer, default 22 (10 pm)
 #' @param quiet default FALSE. whether to echo process messages
 #' @param service_ids (optional) a string from the calendar dataframe identifying a particular service schedule.
 #' @param dow (optional) an integer vector with days of week. monday=1. default: c(1,1,1,1,1,0,0)
-#' @return a gtfs_obj with a dataframe of routes with variables (gtfs_obj$.$routes_frequency) for headway/frequency for a route within a given time frame
+#' @return a dataframe of routes with variables (gtfs_obj$.$routes_frequency) for headway/frequency for a route within a given time frame
 #' @export
 #' @examples 
 #' data(gtfs_obj)
-#' gtfs_obj <- get_route_frequency(gtfs_obj)
-#' x <- order(gtfs_obj$.$routes_frequency$median_headways)
-#' head(gtfs_obj$.$routes_frequency[x,])
+#' routes_frequency <- get_route_frequency(gtfs_obj)
+#' x <- order(routes_frequency$median_headways)
+#' head(routes_frequency[x,])
 
 get_route_frequency <- function(gtfs_obj,
                             start_hour=6,
@@ -114,12 +110,13 @@ get_route_frequency <- function(gtfs_obj,
   if (!quiet) message("Calculating route and stop headways.")
   if( !is.null(gtfs_obj$frequencies) ) {  print("NOTE: A pre-calculated frequencies dataframe exists for this feed already--consider using that.") } 
   # TODO use set_* if gtfs_obj is changed/appended?
-  gtfs_obj <- get_stop_frequency(gtfs_obj, start_hour, 
+  stops_frequency <- get_stop_frequency(gtfs_obj, start_hour, 
                                  end_hour, service_ids, dow)  
-  if (dim(gtfs_obj$.$stops_frequency)[[1]]!=0) {
-    gtfs_obj$.$routes_frequency <- gtfs_obj$.$stops_frequency %>%
+  if (dim(stops_frequency)[[1]]!=0) {
+    routes_frequency <- stops_frequency %>%
       dplyr::group_by(route_id) %>%
-      dplyr::summarise(median_headways = 
+      dplyr::summarise(total_departures = sum(departures),
+                       median_headways = 
                          as.integer(round(median(.data$headway),0)),
                        mean_headways = 
                          as.integer(round(mean(.data$headway),0)),
@@ -130,6 +127,6 @@ get_route_frequency <- function(gtfs_obj,
     warning("failed to calculate frequency--
             try passing a service_id from calendar_df")
   }
-  return(gtfs_obj)
+  return(routes_frequency)
 }
 
